window.Gleam.initSearch([{"doc":"json_typedef","title":"json_typedef","content":"# json_typedef\n\nWork with JSON using a schema! \n\n[![Package Version](https://img.shields.io/hexpm/v/json_typedef)](https://hex.pm/packages/json_typedef)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/json_typedef/)\n\nJSON-Typedef is an easy-to-learn, portable, and standardized way to describe the\nshape of your JSON data. This library provides encoders and decoders for the\nJSON-Typedef schema format, and can generate Gleam encoders and decoders for a\ngiven schema.\n\n- [JSON-Typedef website](https://jsontypedef.com/)\n- [RFC8927](https://datatracker.ietf.org/doc/html/rfc8927)\n\nFor example, if you have this JSON-Typedef schema:\n\n```json\n{\n  &quot;properties&quot;: {\n    &quot;id&quot;: { &quot;type&quot;: &quot;string&quot; },\n    &quot;createdAt&quot;: { &quot;type&quot;: &quot;timestamp&quot; },\n    &quot;karma&quot;: { &quot;type&quot;: &quot;int32&quot; },\n    &quot;isAdmin&quot;: { &quot;type&quot;: &quot;boolean&quot; }\n  }\n}\n```\n\nThen you can use this package to generate this Gleam source code:\n\n```gleam\nimport decode\nimport gleam/json\n\npub type Data {\n  Data(\n    created_at: String,\n    id: String,\n    is_admin: Bool,\n    karma: Int,\n  )\n}\n\npub fn data_decoder() -&gt; decode.Decoder(Data) {\n  decode.into({\n    use created_at &lt;- decode.parameter\n    use id &lt;- decode.parameter\n    use is_admin &lt;- decode.parameter\n    use karma &lt;- decode.parameter\n    Data(created_at:, id:, is_admin:, karma:)\n  })\n  |&gt; decode.field(&quot;createdAt&quot;, decode.string)\n  |&gt; decode.field(&quot;id&quot;, decode.string)\n  |&gt; decode.field(&quot;isAdmin&quot;, decode.bool)\n  |&gt; decode.field(&quot;karma&quot;, decode.int)\n}\n\npub fn data_to_json(data: Data) -&gt; json.Json {\n  json.object([\n    #(&quot;createdAt&quot;, json.string(data.created_at)),\n    #(&quot;id&quot;, json.string(data.id)),\n    #(&quot;isAdmin&quot;, json.bool(data.is_admin)),\n    #(&quot;karma&quot;, json.int(data.karma)),\n  ])\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/json_typedef&gt;.\n","url":"index.html"},{"doc":"json_typedef","title":"CodegenError","content":"pub type CodegenError {\n  CannotConvertEmptyToJsonError\n  EmptyEnumError\n  DuplicatePropertyError(\n    type_name: String,\n    constructor_name: String,\n    property_name: String,\n  )\n  DuplicateConstructorError(name: String)\n  DuplicateTypeError(name: String)\n  DuplicateFunctionError(name: String)\n}\n\nCannotConvertEmptyToJsonError\n\n\nEmptyEnumError\n\n\nDuplicatePropertyError(\n  type_name: String,\n  constructor_name: String,\n  property_name: String,\n)\n\n\nDuplicateConstructorError(name: String)\n\n\nDuplicateTypeError(name: String)\n\n\nDuplicateFunctionError(name: String)\n\n\nSynonyms:\njson_typedef.CodegenError\njson_typedef CodegenError","url":"json_typedef.html#CodegenError"},{"doc":"json_typedef","title":"Generator","content":"pub opaque type Generator\n\n\nSynonyms:\njson_typedef.Generator\njson_typedef Generator","url":"json_typedef.html#Generator"},{"doc":"json_typedef","title":"PropertiesSchema","content":"pub type PropertiesSchema {\n  PropertiesSchema(\n    properties: List(#(String, Schema)),\n    optional_properties: List(#(String, Schema)),\n    additional_properties: Bool,\n  )\n}\n\nPropertiesSchema(\n  properties: List(#(String, Schema)),\n  optional_properties: List(#(String, Schema)),\n  additional_properties: Bool,\n)\n\n\nSynonyms:\njson_typedef.PropertiesSchema\njson_typedef PropertiesSchema","url":"json_typedef.html#PropertiesSchema"},{"doc":"json_typedef","title":"RootSchema","content":"pub type RootSchema {\n  RootSchema(\n    definitions: List(#(String, Schema)),\n    schema: Schema,\n  )\n}\n\nRootSchema(definitions: List(#(String, Schema)), schema: Schema)\n\n\nSynonyms:\njson_typedef.RootSchema\njson_typedef RootSchema","url":"json_typedef.html#RootSchema"},{"doc":"json_typedef","title":"Schema","content":"pub type Schema {\n  Empty\n  Type(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    type_: Type,\n  )\n  Enum(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    variants: List(String),\n  )\n  Properties(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    schema: PropertiesSchema,\n  )\n  Elements(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    schema: Schema,\n  )\n  Values(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    schema: Schema,\n  )\n  Discriminator(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    tag: String,\n    mapping: List(#(String, PropertiesSchema)),\n  )\n  Ref(\n    nullable: Bool,\n    metadata: List(#(String, Dynamic)),\n    name: String,\n  )\n}\n\nEmpty\n Any value. The empty form is like a Java Object or TypeScript any.\n\nType(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  type_: Type,\n)\n A simple built-in type. The type form is like a Java or TypeScript\n primitive type.\n\nEnum(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  variants: List(String),\n)\n One of a fixed set of strings. The enum form is like a Java or TypeScript\n enum.\n\nProperties(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  schema: PropertiesSchema,\n)\n\n\nElements(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  schema: Schema,\n)\n A sequence of some other form. The elements form is like a Java `List&lt;T&gt;`\n or TypeScript `T[]`.\n\nValues(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  schema: Schema,\n)\n A dictionary with string keys and some form values. The values form is\n like a Java `Map&lt;String, T&gt;` or TypeScript `{ [key: string]: T}`.\n\nDiscriminator(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  tag: String,\n  mapping: List(#(String, PropertiesSchema)),\n)\n The discriminator form is like a tagged union.\n\nRef(\n  nullable: Bool,\n  metadata: List(#(String, Dynamic)),\n  name: String,\n)\n The ref form is for re-using schemas, usually so you can avoid repeating\n yourself.\n\nSynonyms:\njson_typedef.Schema\njson_typedef Schema","url":"json_typedef.html#Schema"},{"doc":"json_typedef","title":"Type","content":"pub type Type {\n  Boolean\n  String\n  Timestamp\n  Float32\n  Float64\n  Int8\n  Uint8\n  Int16\n  Uint16\n  Int32\n  Uint32\n}\n\nBoolean\n `true` or `false`\n\nString\n JSON strings\n\nTimestamp\n JSON strings containing an RFC3339 timestamp\n\nFloat32\n JSON numbers\n\nFloat64\n JSON numbers\n\nInt8\n Whole JSON numbers that fit in a signed 8-bit integer\n\nUint8\n Whole JSON numbers that fit in an unsigned 8-bit integer\n\nInt16\n Whole JSON numbers that fit in a signed 16-bit integer\n\nUint16\n Whole JSON numbers that fit in an unsigned 16-bit integer\n\nInt32\n Whole JSON numbers that fit in a signed 32-bit integer\n\nUint32\n Whole JSON numbers that fit in an unsigned 32-bit integer\n\nSynonyms:\njson_typedef.Type\njson_typedef Type","url":"json_typedef.html#Type"},{"doc":"json_typedef","title":"codegen","content":"pub fn codegen() -&gt; Generator\n\nSynonyms:\njson_typedef.codegen\njson_typedef codegen","url":"json_typedef.html#codegen"},{"doc":"json_typedef","title":"decoder","content":"pub fn decoder(\n  data: Dynamic,\n) -&gt; Result(RootSchema, List(DecodeError))\n\nSynonyms:\njson_typedef.decoder\njson_typedef decoder","url":"json_typedef.html#decoder"},{"doc":"json_typedef","title":"generate","content":"pub fn generate(\n  gen: Generator,\n  schema: RootSchema,\n) -&gt; Result(String, CodegenError)\n\nSynonyms:\njson_typedef.generate\njson_typedef generate","url":"json_typedef.html#generate"},{"doc":"json_typedef","title":"generate_decoders","content":"pub fn generate_decoders(gen: Generator, x: Bool) -&gt; Generator\n\nSynonyms:\njson_typedef.generate_decoders\njson_typedef generate_decoders","url":"json_typedef.html#generate_decoders"},{"doc":"json_typedef","title":"generate_encoders","content":"pub fn generate_encoders(gen: Generator, x: Bool) -&gt; Generator\n\nSynonyms:\njson_typedef.generate_encoders\njson_typedef generate_encoders","url":"json_typedef.html#generate_encoders"},{"doc":"json_typedef","title":"root_name","content":"pub fn root_name(gen: Generator, root_name: String) -&gt; Generator\n\nSynonyms:\njson_typedef.root_name\njson_typedef root_name","url":"json_typedef.html#root_name"},{"doc":"json_typedef","title":"to_json","content":"pub fn to_json(schema: RootSchema) -&gt; Json\n\nSynonyms:\njson_typedef.to_json\njson_typedef to_json","url":"json_typedef.html#to_json"},{"doc":"json_typedef","title":"json_typedef","content":" &lt;https://jsontypedef.com/&gt;\n\n &lt;https://datatracker.ietf.org/doc/html/rfc8927&gt;","url":"json_typedef.html"}]);